@@ -3,5 +3,5 @@
 # Released under the MIT License.
 # Copyright, 2023-2024, by Samuel Williams.
 
-require_relative 'bound_endpoint'
-require_relative 'connected_endpoint'
+require_relative "bound_endpoint"
+require_relative "connected_endpoint"
